@@ -77,4 +77,4 @@ class NestedVolumeGroupSerializer(WritableNestedSerializer):
 
     class Meta:
         model = MountedVolume
-        fields = ["id", "url", "display", "vg_name"]
+        fields = ["id", "url", "display"]
