@@ -194,14 +194,11 @@ class DriveTemplateForm(NetBoxModelForm):
         print(f"{self.cleaned_data['size']}")
         drive_type_pk = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
 
-        linux_device = LinuxDevice.objects.create(device='/dev/sda',
+        linux_device = LinuxDevice.objects.create(device=drive.device_name(),
                                                   type='disk',
+                                                  size=self.cleaned_data['size'],
                                                   object_id=drive.pk,
                                                   content_type_id=drive_type_pk)
-        print(drive)
-        print(linux_device)
-        print(template_configuration)
-
         return template_configuration
 
 
