@@ -57,7 +57,7 @@ class Drive(NetBoxModel):
         ordering = ['size']
 
     def __str__(self):
-        return f'{self.identifier}-{self.size}MB-{self.cluster}'
+        return f'{self.identifier} ({self.size}MB {self.cluster})'
 
     def get_absolute_url(self):
         return reverse('plugins:netbox_storage:drive', kwargs={'pk': self.pk})
@@ -134,6 +134,9 @@ class LinuxDevice(NetBoxModel):
     type = models.CharField(
         max_length=255,
     )
+    size = models.FloatField(
+        verbose_name='Size (GB)'
+    )
     content_type = models.ForeignKey(
         to=ContentType,
         on_delete=models.CASCADE
@@ -144,7 +147,7 @@ class LinuxDevice(NetBoxModel):
         fk_field='object_id'
     )
 
-    clone_fields = ['device', 'type', 'content_type', 'object_id']
+    clone_fields = ['device', 'type', 'size', 'content_type', 'object_id']
 
     def __str__(self):
         return f'{self.device}'
